package impl_es

// InfoLog
// @description: 信息日志记录
// parameter:
//		@format:日志格式
//		@args:参数列表
// return:
func (l *Logger) InfoLog(format string, args ...interface{}) {
	info := l.buildEsLog("Info", format, args...)
	l.cache.addCacheLog(info)
}

// DebugLog
// @description: 调试日志记录
// parameter:
//		@format:日志格式
//		@args:参数列表
// return:
func (l *Logger) DebugLog(format string, args ...interface{}) {
	info := l.buildEsLog("Debug", format, args...)
	l.cache.addCacheLog(info)
}

// WarnLog
// @description: 警告日志记录
// parameter:
//		@format:日志格式
//		@args:参数列表
// return:
func (l *Logger) WarnLog(format string, args ...interface{}) {
	info := l.buildEsLog("Warn", format, args...)
	l.cache.addCacheLog(info)
}

// ErrorLog
// @description: 错误日志记录
// parameter:
//		@format:日志格式
//		@args:参数列表
// return:
func (l *Logger) ErrorLog(format string, args ...interface{}) {
	info := l.buildEsLog("Error", format, args...)
	l.cache.addCacheLog(info)
}

// FatalLog
// @description: 致命错误日志记录
// parameter:
//		@format:日志格式
//		@args:参数列表
// return:
func (l *Logger) FatalLog(format string, args ...interface{}) {
	info := l.buildEsLog("Fatal", format, args...)
	l.cache.addCacheLog(info)
}

// CloseLog
// @description: 关闭日志
// parameter:
//		@waitFinish:是否等待日志
// return:
func (l *Logger) CloseLog(waitFinish bool) {}
